=======
Vectors
=======

The vector module provides tools for basic vector math
and differential calculus with respect to 3D Cartesian coordinate
systems. This documentation provides an overview of all the
features offered, and relevant API.


Guide to Vector
===============

.. toctree::
    :maxdepth: 2

    intro
    basics
    coordsys
    fields
    examples

Vector API
==========

.. toctree::
    :maxdepth: 2

    api/classes
    api/orienterclasses
    api/vectorfunctions
